@@ -1,4 +1,5 @@
-from AnyQt.QtWidgets import QApplication
+from AnyQt.QtCore import Qt
+from AnyQt.QtWidgets import QApplication, QGridLayout, QLabel
 
 from Orange.widgets import gui, settings
 from Orange.widgets.utils.signals import Input, Output
@@ -21,20 +22,35 @@ class OWSentimentAnalysis(OWWidget):
 
     method_idx = settings.Setting(1)
     autocommit = settings.Setting(True)
+    language = settings.Setting('English')
     want_main_area = False
     resizing_enabled = False
 
+    METHODS = [
+        Liu_Hu_Sentiment,
+        Vader_Sentiment
+    ]
+    LANG = ['English', 'Slovenian']
+
     def __init__(self):
         super().__init__()
-        self.METHODS = [
-            Liu_Hu_Sentiment(),
-            Vader_Sentiment()
-        ]
         self.corpus = None
 
-        gui.radioButtons(self.controlArea, self, "method_idx", box="Method",
-                         btnLabels=[m.name for m in self.METHODS],
-                         callback=self._method_changed)
+        form = QGridLayout()
+        self.method_box = box = gui.radioButtonsInBox(
+            self.controlArea, self, "method_idx", [], box="Method",
+            orientation=form, callback=self._method_changed)
+        self.liu_hu = gui.appendRadioButton(box, "Liu Hu", addToLayout=False)
+        self.liu_lang = gui.comboBox(None, self, 'language',
+                                     sendSelectedValue=True,
+                                     items=self.LANG,
+                                     callback=self._method_changed)
+        self.vader = gui.appendRadioButton(box, "Vader", addToLayout=False)
+
+        form.addWidget(self.liu_hu, 0, 0, Qt.AlignLeft)
+        form.addWidget(QLabel("Language:"), 0, 1, Qt.AlignRight)
+        form.addWidget(self.liu_lang, 0, 2, Qt.AlignRight)
+        form.addWidget(self.vader, 1, 0, Qt.AlignLeft)
 
         ac = gui.auto_commit(self.controlArea, self, 'autocommit', 'Commit',
                              'Autocommit is on')
@@ -51,7 +67,10 @@ class OWSentimentAnalysis(OWWidget):
     def commit(self):
         if self.corpus is not None:
             method = self.METHODS[self.method_idx]
-            out = method.transform(self.corpus)
+            if self.method_idx == 0:
+                out = method(language=self.language).transform(self.corpus)
+            else:
+                out = method().transform(self.corpus)
             self.Outputs.corpus.send(out)
         else:
             self.Outputs.corpus.send(None)
@@ -61,7 +80,6 @@ class OWSentimentAnalysis(OWWidget):
             ('Method', self.METHODS[self.method_idx].name),
         ))
 
-
 def main():
     app = QApplication([])
     widget = OWSentimentAnalysis()
